@@ -1,4 +1,4 @@
 from .file_loader import FileLoader
 from .viz import make_gif
 from .types import event_dtype
-from .hdf5tools import HDF5FileIterator
\ No newline at end of file
+from .hdf5tools import HDF5FileIterator, HDF5File
\ No newline at end of file
