@@ -3,4 +3,4 @@ from aertb.core.loaders.bin_loader import BinLoader
 from aertb.core.loaders.aedat_loader import AedatLoader
 from aertb.core.loaders.interface import FileLoaderInterface
 
-__all__ = ['DatLoader', 'BinLoader', 'FileLoaderInterface', 'AedatLoader']
\ No newline at end of file
+__all__ = ['DatLoader', 'BinLoader', 'AedatLoader', 'FileLoaderInterface']
\ No newline at end of file
